==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_id.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=id
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'URL situs anda', # MODIF
	'form_pet_aucune_signature' => 'Tidak ada tanda tangan yang cocok dengan kode ini...', # MODIF
	'form_pet_confirmation' => 'Silakan konfirmasi tanda tangan anda:',
	'form_pet_deja_signe' => 'Anda telah menandatangani teks ini.',
	'form_pet_envoi_mail_confirmation' => 'Sebuah e-mail konfirmasi telah dikirimkan kepada anda. Anda harus mengunjungi URL yang tercantum dalam email ini untuk menvalidasi tanda tangan anda.', # MODIF
	'form_pet_mail_confirmation' => 'Halo,

Anda telah menandatangani petisi:
@titre@.

Anda memberikan informasi berikut:
    Nama: @nom_email@
    Situs: @nom_site@ - @url_site@
@message@

PESAN...
Untuk menvalidasi tanda tangan anda, anda hanya perlu mengunjungi
alamat di bawah (atau permohonan anda
akan ditolak):
    @url@

Terima kasih atas partisipasi anda!
',
	'form_pet_nom_site2' => 'Nama situs web anda', # MODIF
	'form_pet_probleme_technique' => 'Permasalahan teknis, sistem tanda tangan untuk sementara waktu terganggu.',
	'form_pet_signature_validee' => 'Tanda tangan anda sah. Terima kasih!',
	'form_pet_site_deja_enregistre' => 'Situs ini telah terdaftar',
	'form_pet_url_invalide' => 'URL yang anda berikan tidak sah.',
	'form_pet_votre_email' => 'Alamat e-mail anda',
	'form_pet_votre_nom' => 'Nama atau alias anda', # MODIF
	'form_pet_votre_site' => 'Jika anda memiliki sebuah situs web, anda dapat memasukkannya di bawah',

	// I
	'info_adresse_email' => 'ALAMAT E-MAIL:',
	'info_site_web' => 'SITUS WEB:',

	// L
	'lien_reponse_article' => 'Balasan pada artikel'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_id.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=id
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Aktifkan petisi',
	'bouton_radio_pas_petition' => 'Tidak ada petisi',
	'bouton_radio_petition_activee' => 'Petisi diaktifkan',
	'bouton_radio_supprimer_petition' => 'Hapus petisi',

	// F
	'form_pet_adresse_site' => 'URL situs anda', # MODIF
	'form_pet_aucune_signature' => 'Tidak ada tanda tangan yang cocok dengan kode ini...', # MODIF
	'form_pet_confirmation' => 'Silakan konfirmasi tanda tangan anda:',
	'form_pet_deja_signe' => 'Anda telah menandatangani teks ini.',
	'form_pet_envoi_mail_confirmation' => 'Sebuah e-mail konfirmasi telah dikirimkan kepada anda. Anda harus mengunjungi URL yang tercantum dalam email ini untuk menvalidasi tanda tangan anda.', # MODIF
	'form_pet_mail_confirmation' => 'Halo,

Anda telah menandatangani petisi:
@titre@.

Anda memberikan informasi berikut:
    Nama: @nom_email@
    Situs: @nom_site@ - @url_site@
@message@

PESAN...
Untuk menvalidasi tanda tangan anda, anda hanya perlu mengunjungi
alamat di bawah (atau permohonan anda
akan ditolak):
    @url@

Terima kasih atas partisipasi anda!
',
	'form_pet_nom_site2' => 'Nama situs web anda', # MODIF
	'form_pet_probleme_technique' => 'Permasalahan teknis, sistem tanda tangan untuk sementara waktu terganggu.',
	'form_pet_signature_validee' => 'Tanda tangan anda sah. Terima kasih!',
	'form_pet_site_deja_enregistre' => 'Situs ini telah terdaftar',
	'form_pet_url_invalide' => 'URL yang anda berikan tidak sah.',
	'form_pet_votre_email' => 'Alamat e-mail anda',
	'form_pet_votre_nom' => 'Nama atau alias anda', # MODIF
	'form_pet_votre_site' => 'Jika anda memiliki sebuah situs web, anda dapat memasukkannya di bawah',

	// I
	'info_adresse_email' => 'ALAMAT E-MAIL:',
	'info_site_web' => 'SITUS WEB:',

	// L
	'lien_reponse_article' => 'Balasan pada artikel'
);

?>
